==> knative-model-4.5.2-sources.jar: io/fabric8/knative/messaging/v1alpha1/InMemoryChannelListFluentImpl.java <==
package io.fabric8.knative.messaging.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class InMemoryChannelListFluentImpl<A extends InMemoryChannelListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements InMemoryChannelListFluent<A>{

    private String apiVersion;
    private List<InMemoryChannelBuilder> items;
    private String kind;
    private ListMeta metadata;

    public InMemoryChannelListFluentImpl(){
    }
    public InMemoryChannelListFluentImpl(InMemoryChannelList instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,InMemoryChannel item){
            if (this.items == null) {this.items = new ArrayList<InMemoryChannelBuilder>();}
            InMemoryChannelBuilder builder = new InMemoryChannelBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,InMemoryChannel item){
            if (this.items == null) {this.items = new ArrayList<InMemoryChannelBuilder>();}
            InMemoryChannelBuilder builder = new InMemoryChannelBuilder(item);
            if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
            if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
             return (A)this;
    }

    public A addToItems(InMemoryChannel... items){
            if (this.items == null) {this.items = new ArrayList<InMemoryChannelBuilder>();}
            for (InMemoryChannel item : items) {InMemoryChannelBuilder builder = new InMemoryChannelBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<InMemoryChannel> items){
            if (this.items == null) {this.items = new ArrayList<InMemoryChannelBuilder>();}
            for (InMemoryChannel item : items) {InMemoryChannelBuilder builder = new InMemoryChannelBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(InMemoryChannel... items){
            for (InMemoryChannel item : items) {InMemoryChannelBuilder builder = new InMemoryChannelBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<InMemoryChannel> items){
            for (InMemoryChannel item : items) {InMemoryChannelBuilder builder = new InMemoryChannelBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<InMemoryChannel> getItems(){
            return build(items);
    }

    public List<InMemoryChannel> buildItems(){
            return build(items);
    }

    public InMemoryChannel buildItem(int index){
            return this.items.get(index).build();
    }

    public InMemoryChannel buildFirstItem(){
            return this.items.get(0).build();
    }

    public InMemoryChannel buildLastItem(){
            return this.items.get(items.size() - 1).build();
    }

    public InMemoryChannel buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<InMemoryChannelBuilder> predicate){
            for (InMemoryChannelBuilder item: items) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<InMemoryChannelBuilder> predicate){
            for (InMemoryChannelBuilder item: items) { if(predicate.apply(item)){return true;} } return false;
    }

    public A withItems(List<InMemoryChannel> items){
            if (this.items != null) { _visitables.get("items").removeAll(this.items);}
            if (items != null) {this.items = new ArrayList<InMemoryChannelBuilder>(); for (InMemoryChannel item : items){this.addToItems(item);}} else { this.items = new ArrayList<InMemoryChannelBuilder>();} return (A) this;
    }

    public A withItems(InMemoryChannel... items){
            if (this.items != null) {this.items.clear();}
            if (items != null) {for (InMemoryChannel item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems(){
            return items != null && !items.isEmpty();
    }

    public InMemoryChannelListFluent.ItemsNested<A> addNewItem(){
            return new ItemsNestedImpl();
    }

    public InMemoryChannelListFluent.ItemsNested<A> addNewItemLike(InMemoryChannel item){
            return new ItemsNestedImpl(-1, item);
    }

    public InMemoryChannelListFluent.ItemsNested<A> setNewItemLike(int index,InMemoryChannel item){
            return new ItemsNestedImpl(index, item);
    }

    public InMemoryChannelListFluent.ItemsNested<A> editItem(int index){
            if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
            return setNewItemLike(index, buildItem(index));
    }

    public InMemoryChannelListFluent.ItemsNested<A> editFirstItem(){
            if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
            return setNewItemLike(0, buildItem(0));
    }

    public InMemoryChannelListFluent.ItemsNested<A> editLastItem(){
            int index = items.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
            return setNewItemLike(index, buildItem(index));
    }

    public InMemoryChannelListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<InMemoryChannelBuilder> predicate){
            int index = -1;
            for (int i=0;i<items.size();i++) { 
            if (predicate.apply(items.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
            return setNewItemLike(index, buildItem(index));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    public ListMeta getMetadata(){
            return this.metadata;
    }

    public A withMetadata(ListMeta metadata){
            this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public A withNewMetadata(String _continue,String resourceVersion,String selfLink){
            return (A)withMetadata(new ListMeta(_continue, resourceVersion, selfLink));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            InMemoryChannelListFluentImpl that = (InMemoryChannelListFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (items != null ? !items.equals(that.items) :that.items != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            return true;
    }


    public class ItemsNestedImpl<N> extends InMemoryChannelFluentImpl<InMemoryChannelListFluent.ItemsNested<N>> implements InMemoryChannelListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final InMemoryChannelBuilder builder;
        private final int index;
    
            ItemsNestedImpl(int index,InMemoryChannel item){
                    this.index = index;
                    this.builder = new InMemoryChannelBuilder(this, item);
            }
            ItemsNestedImpl(){
                    this.index = -1;
                    this.builder = new InMemoryChannelBuilder(this);
            }
    
    public N and(){
            return (N) InMemoryChannelListFluentImpl.this.setToItems(index, builder.build());
    }
    public N endItem(){
            return and();
    }

}


}

==> knative-model-4.6.0-sources.jar: io/fabric8/knative/messaging/v1alpha1/InMemoryChannelListFluentImpl.java <==
package io.fabric8.knative.messaging.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class InMemoryChannelListFluentImpl<A extends InMemoryChannelListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements InMemoryChannelListFluent<A>{

    private String apiVersion;
    private List<InMemoryChannelBuilder> items;
    private String kind;
    private ListMeta metadata;

    public InMemoryChannelListFluentImpl(){
    }
    public InMemoryChannelListFluentImpl(InMemoryChannelList instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,InMemoryChannel item){
            if (this.items == null) {this.items = new ArrayList<InMemoryChannelBuilder>();}
            InMemoryChannelBuilder builder = new InMemoryChannelBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,InMemoryChannel item){
            if (this.items == null) {this.items = new ArrayList<InMemoryChannelBuilder>();}
            InMemoryChannelBuilder builder = new InMemoryChannelBuilder(item);
            if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
            if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
             return (A)this;
    }

    public A addToItems(InMemoryChannel... items){
            if (this.items == null) {this.items = new ArrayList<InMemoryChannelBuilder>();}
            for (InMemoryChannel item : items) {InMemoryChannelBuilder builder = new InMemoryChannelBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<InMemoryChannel> items){
            if (this.items == null) {this.items = new ArrayList<InMemoryChannelBuilder>();}
            for (InMemoryChannel item : items) {InMemoryChannelBuilder builder = new InMemoryChannelBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(InMemoryChannel... items){
            for (InMemoryChannel item : items) {InMemoryChannelBuilder builder = new InMemoryChannelBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<InMemoryChannel> items){
            for (InMemoryChannel item : items) {InMemoryChannelBuilder builder = new InMemoryChannelBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<InMemoryChannel> getItems(){
            return build(items);
    }

    public List<InMemoryChannel> buildItems(){
            return build(items);
    }

    public InMemoryChannel buildItem(int index){
            return this.items.get(index).build();
    }

    public InMemoryChannel buildFirstItem(){
            return this.items.get(0).build();
    }

    public InMemoryChannel buildLastItem(){
            return this.items.get(items.size() - 1).build();
    }

    public InMemoryChannel buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<InMemoryChannelBuilder> predicate){
            for (InMemoryChannelBuilder item: items) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<InMemoryChannelBuilder> predicate){
            for (InMemoryChannelBuilder item: items) { if(predicate.apply(item)){return true;} } return false;
    }

    public A withItems(List<InMemoryChannel> items){
            if (this.items != null) { _visitables.get("items").removeAll(this.items);}
            if (items != null) {this.items = new ArrayList<InMemoryChannelBuilder>(); for (InMemoryChannel item : items){this.addToItems(item);}} else { this.items = new ArrayList<InMemoryChannelBuilder>();} return (A) this;
    }

    public A withItems(InMemoryChannel... items){
            if (this.items != null) {this.items.clear();}
            if (items != null) {for (InMemoryChannel item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems(){
            return items != null && !items.isEmpty();
    }

    public InMemoryChannelListFluent.ItemsNested<A> addNewItem(){
            return new ItemsNestedImpl();
    }

    public InMemoryChannelListFluent.ItemsNested<A> addNewItemLike(InMemoryChannel item){
            return new ItemsNestedImpl(-1, item);
    }

    public InMemoryChannelListFluent.ItemsNested<A> setNewItemLike(int index,InMemoryChannel item){
            return new ItemsNestedImpl(index, item);
    }

    public InMemoryChannelListFluent.ItemsNested<A> editItem(int index){
            if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
            return setNewItemLike(index, buildItem(index));
    }

    public InMemoryChannelListFluent.ItemsNested<A> editFirstItem(){
            if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
            return setNewItemLike(0, buildItem(0));
    }

    public InMemoryChannelListFluent.ItemsNested<A> editLastItem(){
            int index = items.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
            return setNewItemLike(index, buildItem(index));
    }

    public InMemoryChannelListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<InMemoryChannelBuilder> predicate){
            int index = -1;
            for (int i=0;i<items.size();i++) { 
            if (predicate.apply(items.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
            return setNewItemLike(index, buildItem(index));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    public ListMeta getMetadata(){
            return this.metadata;
    }

    public A withMetadata(ListMeta metadata){
            this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink){
            return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            InMemoryChannelListFluentImpl that = (InMemoryChannelListFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (items != null ? !items.equals(that.items) :that.items != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            return true;
    }


    public class ItemsNestedImpl<N> extends InMemoryChannelFluentImpl<InMemoryChannelListFluent.ItemsNested<N>> implements InMemoryChannelListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final InMemoryChannelBuilder builder;
        private final int index;
    
            ItemsNestedImpl(int index,InMemoryChannel item){
                    this.index = index;
                    this.builder = new InMemoryChannelBuilder(this, item);
            }
            ItemsNestedImpl(){
                    this.index = -1;
                    this.builder = new InMemoryChannelBuilder(this);
            }
    
    public N and(){
            return (N) InMemoryChannelListFluentImpl.this.setToItems(index, builder.build());
    }
    public N endItem(){
            return and();
    }

}


}
